<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Tweak</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Η εφαρμογή αυτή είναι μόνο για Xfce</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Λογισμικό (xrandr) Φωτεινότητα</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Οπίσθιο φωτισμό</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>Έξοδος </translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="586"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <location filename="../defaultlook.cpp" line="610"/>
        <location filename="../defaultlook.cpp" line="621"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="147"/>
        <source>Xfce Settings</source>
        <translation>Ρυθμίσεις Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσαρμόστε τον πίνακα&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="48"/>
        <location filename="../defaultlook.ui" line="161"/>
        <source>Panel</source>
        <translation>Πίνακας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="68"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρυθμίστε των παραθύρων και τις συντομεύσεις&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="82"/>
        <source>Window Manager</source>
        <translation>Διαχειριστή παραθύρων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="102"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσαρμόστε την εμφάνιση της επιφάνειας εργασίας σας&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="116"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Help</source>
        <translation>Βοήθεια </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1701"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1704"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1711"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="169"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="189"/>
        <source>Backup current panel configuration</source>
        <translation>Backup του τρέχουσα διαμόρφωση Πανελ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="196"/>
        <source>Restore backup panel configuration</source>
        <translation>Επαναφορά προεπιλεγμένων ρυθμίσεων του Πανελ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="203"/>
        <source>Restore default panel</source>
        <translation>Επαναφορά προεπιλεγμένο Πανελ </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="216"/>
        <location filename="../defaultlook.ui" line="1416"/>
        <source>Affects 1st panel</source>
        <translation>Επηρεάζει τον 1ο πίνακα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Display panel vertically</source>
        <translation>Απεικόνιση οριζοντίως το προεπιλεγμένο Panel </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <location filename="../defaultlook.ui" line="1329"/>
        <source>Bottom</source>
        <translation>Κάτω </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="248"/>
        <location filename="../defaultlook.ui" line="1339"/>
        <source>Top</source>
        <translation>Πάνω</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="256"/>
        <source>Display panel horizontally</source>
        <translation>Απεικόνιση οριζοντίως το προεπιλεγμένο Πανελ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="276"/>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Left</source>
        <translation>Αριστερό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="281"/>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Right</source>
        <translation>Δεξί</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="289"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Επηρεάζει όλους τους πίνακες&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="309"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Κουμπιά παραθύρων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="324"/>
        <location filename="../defaultlook.ui" line="427"/>
        <location filename="../defaultlook.ui" line="618"/>
        <location filename="../defaultlook.ui" line="748"/>
        <location filename="../defaultlook.ui" line="871"/>
        <location filename="../defaultlook.ui" line="878"/>
        <location filename="../defaultlook.ui" line="971"/>
        <location filename="../defaultlook.ui" line="1287"/>
        <location filename="../defaultlook.ui" line="1365"/>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Theme</source>
        <translation>Θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="361"/>
        <source>Theme Options</source>
        <translation>Επιλογές θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="391"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Διόρθωση ορισμένων πεδία ιστοσελίδας όταν χρησιμοποιείται το σκοτεινό θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="394"/>
        <source>Firefox dark theme tweak</source>
        <translation>Διόρθωση του σκοτεινού θέματος του Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="401"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Διόρθωση πλαίσιο εισαγωγής HexChat στο σκοτεινό θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="453"/>
        <source>Undo</source>
        <translation>Αναίρεση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="460"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="467"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θεμάτωνν του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="478"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Αποθηκεύστε τις τρέχουσες ρυθμίσεις ως θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compositor</source>
        <translation>Συνθέτης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Εκτέλεση εργαλείο διαμόρφωσης Compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Compton settings</source>
        <translation>ρυθμίσεις Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="540"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρυθμίσεις Xfce Compositor&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Xfwm Settings</source>
        <translation>Ρυθμίσεις Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>None</source>
        <translation>κανένα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="572"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Συνθέτης Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="585"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Επεξεργασία compton.conf απευθείας στον κειμενογράφο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Edit compton.conf</source>
        <translation>Επεξεργασία compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="645"/>
        <source>Transparency and shadow options</source>
        <translation>επιλογές διαφάνειας και σκιάς</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="652"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Η αλλαγή της λειτουργίας VBlank μπορεί να βοηθήσει στην ανακούφιση ορισμένων ζητημάτων σχισίματος οθόνης. Δείτε Βοήθεια για περισσότερες πληροφορίες.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="655"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="663"/>
        <source>auto</source>
        <translation>αυτόματο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="668"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="673"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="678"/>
        <source>off</source>
        <translation>τίποτα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="888"/>
        <source>Config Options</source>
        <translation>Επιλογές διαμόρφωσης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1423"/>
        <source>Systray Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1434"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1439"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1444"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1449"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1478"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Επαναφέρετε το Lightdm (οθόνη σύνδεσης) στο προεπιλεγμένο θέμα του συστήματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="896"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Επαναφορά του Thunar Custom δεξί κλικ ενεργειών στις προεπιλογές του συστήματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1501"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Χρησιμοποιήστε το πρόγραμμα οδήγησης intel αντί του προεπιλεγμένου προγράμματος οδήγησης &quot;modesetting&quot; (απαιτείται επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1508"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ΣΗΜΕΙΩΣΗ: τα υπάρχοντα /etc/X11/xorg.conf.d/20-intel.conf θα δημιουργηθούν αντίγραφα ασφαλείας στο αρχικό φάκελο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Χρησιμοποιήστε την επιλογή tearfree amdgpu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1526"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ΣΗΜΕΙΩΣΗ: τα υπάρχοντα /etc/X11/xorg.conf.d/20-amd.conf θα δημιουργηθούν αντίγραφα ασφαλείας στο αρχικό φάκελο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1537"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Χρησιμοποιήστε την επιλογή tearfree radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1544"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ΣΗΜΕΙΩΣΗ: τα υπάρχοντα /etc/X11/xorg.conf.d/20-radeon.conf θα δημιουργηθούν αντίγραφα ασφαλείας στο αρχικό φάκελο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Hardware Backlight</source>
        <translation>Οπίσθιο φωτισμό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="714"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις οθόνης&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="741"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Επιλέξτε οθόνη για τροποποιήσεις xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>Resolution</source>
        <translation>Ανάλυση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="781"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation> &lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ανά οθόνη&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Λογισμικό (xrandr) Φωτεινότητα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="798"/>
        <location filename="../defaultlook.ui" line="812"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="805"/>
        <source>GTK scaling</source>
        <translation>Κλίμακα GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="832"/>
        <source>xrandr Scaling</source>
        <translation>Κλίμακα xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="985"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <location filename="../defaultlook.ui" line="1053"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1063"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1199"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <location filename="../defaultlook.ui" line="1376"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1014"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1035"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1042"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1084"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1098"/>
        <location filename="../defaultlook.ui" line="1206"/>
        <location filename="../defaultlook.ui" line="1383"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1182"/>
        <location filename="../defaultlook.ui" line="1280"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1318"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Other</source>
        <translation>Άλλα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1567"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="917"/>
        <source>Show systray (notification area) frame</source>
        <translation>Εμφάνιση πλαισίου systray (περιοχή ειδοποίησης)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="924"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Εμφάνιση παράθυρα από όλους τους χώρους εργασίας στον πίνακα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Enable single-click on desktop</source>
        <translation>Ενεργοποίηση του μονό κλικ στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="938"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ενεργοποιήστε την αδρανοποίηση στο μενού Αποσύνδεση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Ενεργοποιήστε την τοποθέτηση εσωτερικών μονάδων δίσκου από μη χρήστες root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1492"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="945"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Σημείωση: σε κατάσταση αδρανοποίησης, το swap πρέπει να είναι &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="931"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Απενεργοποιήστε τη συντόμευση των μακροχρόνιων ονομάτων αρχείων στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Ενεργοποίηση του μονό κλικ στο Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Password for administrative tasks:</source>
        <translation>Κωδικός πρόσβασης για τις διοικητικές εργασίες:</translation>
    </message>
    <message>
        <source>User</source>
        <translation type="vanished">Χρήστης</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="585"/>
        <source>About MX Tweak</source>
        <translation>Περί MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="586"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="587"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Πρόγραμμα για γρήγορη προεπιλογή αλλαγές θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="589"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="590"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="591"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="622"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Ολοκληρώθηκε! Το Firefox μπορεί να χρειαστεί επανεκκίνηση για να ισχύσουν οι αλλαγές</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Η εφαρμογή αυτή είναι μόνο για Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="806"/>
        <source>Panel settings</source>
        <translation>Ρυθμίσεις του Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="807"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Οι τρέχουσες ρυθμίσεις του Panel  σας δημιουργήσει αντίγραφα ασφαλείας σε έναν κρυφό φάκελο που ονομάζεται .restore στο φάκελο /home (~/.restore /)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1408"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1745"/>
        <source>Choose a theme set</source>
        <translation>Επιλέξτε ένα σύνολο θέματος</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θεμάτωνν του χρήστη</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Νέο θέμα</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Εισαγάγετε όνομα για το νέο θέμα</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Κουμπιά παραθύρων</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εμφάνιση&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Εμφάνιση ετικετών στα κουμπιά</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Χρήση επίπεδων κουμπιών</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Εμφάνιση χειρολαβής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Σειρά ταξινόμησης:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Χρονοσήμανση</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Ομαδοποίηση τίτλου και χρόνου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Τίτλος παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Ομαδοποίηση τίτλου και τίτλου παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Κανένα, να επιτρέπεται η μεταφορά και απόθεση (drag-and-drop)</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Συμπεριφορά&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Ομαδοποίηση παραθύρων:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Ποτέ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Πάντα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Ενέργεια μεσαίου κλικ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Κλείσιμο παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Ελαχιστοποίηση παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Επαναφορά ελαχιστοποίησης των παραθύρων στο τωρινό χώρο εργασίας</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Σχεδίαση του περιγράμματος ενός παραθύρου όταν περνάει πάνω από ένα πλήκτρο</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Εναλλαγή παραθύρων με χρήση της ροδέλας του ποντικιού</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Φιλτράρισμα&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Προβολή παραθύρων από όλους τους χώρους εργασίας ή παράθυρα προβολής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Εμφάνιση μόνο ελαχιστοποιημένων εφαρμογών</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Προβολή παραθύρων από όλα τα monitor</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Αναδυόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Windows κατά τη μετακίνηση</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις αδιαφάνειας&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Διακοσμητικά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Εμφάνιση σκιών κάτω από τα παράθυρα αποβάθρας</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Εμφάνιση σκιών στα αναδυόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Τα Windows κατά τη διάρκεια της αλλαγής μεγέθους</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Εμφάνιση σκιών κάτω από κανονικά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις χαρακτηριστικών&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Προβολή προεπισκόπησης παραθύρων αντί για εικονίδια</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Προβάλετε απευθείας τα παράθυρα επικάλυψης πλήρους οθόνης</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Ανενεργά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Συγχρονισμός του σχεδίου με κατακόρυφο κενό</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Ρυθμίσεις συνθέτη Xfwm</translation>
    </message>
</context>
</TS>
